'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ago = ago;
exports.numberToString = numberToString;
exports.stringToNumber = stringToNumber;
exports.HHMMtoTime = HHMMtoTime;
exports.toSlug = toSlug;
exports.deepEquals = deepEquals;
exports.padLeft = padLeft;
exports.padRight = padRight;
exports.padArray = padArray;
exports.randomArrayItem = randomArrayItem;
exports.isEmail = isEmail;
exports.isAlphanumeric = isAlphanumeric;
exports.isAlphanumericUnderscore = isAlphanumericUnderscore;
exports.isLatLngValid = isLatLngValid;
exports.isJson = isJson;
exports.makeAcronym = makeAcronym;
exports.arrayValueFromLetter = arrayValueFromLetter;
exports.replaceAt = replaceAt;
exports.shorten = shorten;

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ago(date, short) {
  if (!date) {
    return null;
  }
  var m = (0, _moment2.default)();
  var i18nPostfix = short ? '_short' : '';

  if (m.diff(date) < 240000) {
    // 4 minutes
    return { key: 'other.datetime.just_now' + i18nPostfix };
  }

  var dayDiff = m.diff(date, 'day');
  if (!dayDiff) {
    var hrDiff = m.diff(date, 'hour');
    if (!hrDiff) {
      var minDiff = m.diff(date, 'minute');
      return { key: 'other.datetime.minute_ago' + i18nPostfix, params: { smart_count: minDiff } };
    }
    return { key: 'other.datetime.hour_ago' + i18nPostfix, params: { smart_count: hrDiff } };
  } else if (dayDiff <= 7) {
    return { key: 'other.datetime.day_ago' + i18nPostfix, params: { smart_count: dayDiff } };
  }

  var curYear = new Date().getFullYear();
  var dateYear = new Date(date).getFullYear();

  return (0, _moment2.default)(date).format(curYear === dateYear ? 'MMM D' : 'MMM D YYYY');
}

function numberToString(number) {
  return String(number).replace(/\B(?=(\d{3})+(?!\d))/g, ',');
}

function stringToNumber(msg) {
  var result = 0;
  if (msg) {
    for (var i = 0; i < msg.length; i++) {
      result += msg.charCodeAt(i);
    }
  }
  return result;
}

// export function moneyFormat(val, hideDecimals, hideCommas) {
//   let money = parseFloat(val);
//   if (!money) { return i18n.t('general.free'); }
//   money = hideDecimals ? Math.round(money) : money.toFixed(2)
//   if (!hideCommas) {
//     money = money.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',');
//   }
//   return i18n.t('general.currency', {money});
// };

// export function timeFormat(val) {
//   const parsedValue = parseInt(val);
//   const minute = parsedValue % 60;
//   const hour = Math.floor(parsedValue / 60);
//   if (!hour) { return i18n.t('general.minute', {count: minute}); }
//   if (!minute) { return i18n.t('general.hour', {count: hour}); }
//   return i18n.t('general.time_hm', {h: hour, m: minute});
// }

function HHMMtoTime(hhmm, short) {
  var hh = Number(hhmm.substr(0, 2));
  var mm = hhmm.substr(2);
  var am = short ? 'a' : 'am';
  var pm = short ? 'p' : 'pm';
  var ap = hh >= 12 && hh !== 24 ? pm : am;
  var hhRet = hh === 0 || hh === 12 ? 12 : hh % 12;
  if (mm === '00') {
    return hhRet + ap;
  }
  return hhRet + ':' + mm + ap;
}

function toSlug(str, allowNumbers) {
  var slug = str.replace(/\s+/g, '-');
  return allowNumbers ? (0, _lodash.deburr)(slug.replace(/[^a-zA-Z0-9\-]/g, '')).toLowerCase() : (0, _lodash.deburr)(slug.replace(/[^a-zA-Z\-]/g, '')).toLowerCase();
}

function deepEquals(obj1, obj2) {
  return JSON.stringify(obj1) === JSON.stringify(obj2);
}

// Note, current it only works properly when [pad] is one character long
function padLeft(str, len, pad) {
  return Array(len + 1 - str.length).join(pad) + str;
}

// Note, current it only works properly when [pad] is one character long
function padRight(str, len, pad) {
  return str + Array(len + 1 - str.length).join(pad);
}

function padArray(arr, len, fill) {
  return arr.concat(Array(len).fill(fill)).slice(0, len);
}

function randomArrayItem(arr) {
  return arr[Math.floor(Math.random() * arr.length)];
}

function isEmail(str) {
  var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
  return re.test(str);
}

function isAlphanumeric(str) {
  var re = /^[a-z0-9]+$/i;
  return re.test(str);
}

function isAlphanumericUnderscore(str) {
  var re = /^\w+$/;
  return re.test(str);
}

function isLatLngValid(latVal, lngVal) {
  var lat = Number(latVal);
  var lng = Number(lngVal);
  return lat >= -90 && lat <= 90 && lng >= -180 && lng <= 180;
}

function isJson(str) {
  return typeof str === 'string' && /^[\],:{}\s]*$/.test(str.replace(/\\["\\\/bfnrtu]/g, '@').replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']').replace(/(?:^|:|,)(?:\s*\[)+/g, ''));
}

function makeAcronym(name) {
  var len = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 3;

  if (!name || !name.trim().length) {
    return '.';
  }
  var arr = name.split(' ').splice(0, len);
  return arr.map(function (str) {
    var s = str && str.replace(/\W+/g, '');
    return s && s.toUpperCase().charAt(0);
  }).filter(function (s) {
    return s;
  }).join('');
}

function arrayValueFromLetter(str, arr) {
  var maxLen = arr.length;

  var ltr = (str || '')[0];
  if (!isNaN(ltr)) {
    if (str && str.length > 1) {
      for (var i = 1; i < str.length; i++) {
        ltr = str[i];
        if (ltr && isNaN(ltr)) {
          // Exit
          i = str.length;
        }
      }
    }

    if (!ltr || !isNaN(ltr)) {
      ltr = 'A';
    }
  }

  var ltrNum = parseInt(ltr, 36) - 9;
  if (!ltrNum || isNaN(ltrNum)) {
    ltrNum = 1;
  }

  var index = Math.floor(maxLen / ltrNum);
  if (index === maxLen) {
    index = 0;
  }
  return arr[index];
}

function replaceAt(str, i, replaceStr) {
  var replace = String(replaceStr);
  return str.substr(0, i) + replace + str.substr(i + replace.length);
}

function shorten(strVar, len) {
  if (!strVar) {
    return '';
  }
  var str = strVar.trim();
  return str.substr(0, len) + (str.length > len ? '...' : '');
}

// export function getAllUrlVariations(str, includeNonProto) {
//   let url = str.toLowerCase();
//   url = (url.indexOf('http://') === 0 || url.indexOf('https://') === 0)
//     ? url.substr(url.indexOf('http://') === 0 ? 7 : 8)
//     : url;
//   url = url.indexOf('www.') === 0
//     ? url.substr(4)
//     : url;
//
//   const ret = [
//     'http://' + url,
//     'https://' + url,
//     'http://www.' + url,
//     'https://www.' + url
//   ];
//
//   if (includeNonProto) {
//     ret.push(url);
//     ret.push('www.' + url);
//   }
//
//   return ret;
// }
//
// export function makeUrlReadable(str, maxUriPaths = 3, maxPathStrLen = 5, maxStrLen = 38) {
//   const dissectedUrl = dissectUrl(str);
//   const domainUrl = expandUrl(dissectedUrl);
//
//   if (!dissectedUrl.uri) {
//     return domainUrl;
//   }
//
//   let uriPaths = dissectedUrl.uri.split('/');
//   if (uriPaths.length >= 2) {
//     uriPaths = uriPaths.slice(0,maxUriPaths);
//     uriPaths = uriPaths.map(path =>
//       path.length > maxPathStrLen ? path.substr(0, maxPathStrLen) + '...' : path
//     );
//   }
//
//   const url = domainUrl + '/' + uriPaths.join('/');
//   if (url.length > maxStrLen) {
//     return url.substr(0, maxStrLen) + '...';
//   }
//
//   return url;
// }
//
//
// export function dissectUrl(str) {
//   const strLower = str.toLowerCase();
//
//   let url; let https;
//   if (strLower.indexOf('https://') === 0 || strLower.indexOf('http://') === 0) {
//     https = strLower.indexOf('https://') === 0;
//     url = str.substr(https ? 8 : 7);
//   } else {
//     https = false;
//     url = str;
//   }
//
//   const naked = url.indexOf('www.') !== 0;
//   const paths = url.split('/').filter(p => p.trim());
//   const domain = paths[0].substr(naked ? 0 : 4).toLowerCase();
//   paths.shift();
//
//   return {
//     https, domain, naked,
//     uri: paths.length ? paths.join('/') : ''
//   };
// }
//
// export function expandUrl(obj, includeUri) {
//   let url = obj.https ? 'https://' : 'http://';
//   url += obj.naked ? '' : 'www.';
//   url += obj.domain;
//   return includeUri ? (url + '/' + obj.uri) : url;
// }
//
// export function isValidUrl(str) {
//   // const pattern = /(http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/;
//   const pattern = /^(http:\/\/www\.|https:\/\/www\.|http:\/\/|https:\/\/)?[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(:[0-9]{1,5})?(\/.*)?$/g;
//   return pattern.test(str.toLowerCase());
// }